@@ -19,13 +19,18 @@ if [ "${CXX}" = "g++" ]; then
     CC=gcc-4.8
 fi
 
+echo "travis_fold:start:cmake\nRunning cmake..."
 cmake -LA \
     -DCMAKE_BUILD_TYPE=${BUILD_TYPE} \
-    -DOSMPBF_INCLUDE_DIR=${TRAVIS_BUILD_DIR}/../OSM-binary/include \
-    -DOSMPBF_LIBRARY=${TRAVIS_BUILD_DIR}/../OSM-binary/src/libosmpbf.a \
     ${WORKAROUND} \
     ..
+echo "travis_fold:end:cmake"
 
+echo "travis_fold:start:make\nRunning make..."
 make VERBOSE=1
+echo "travis_fold:end:make"
+
+echo "travis_fold:start:ctest\nRunning ctest..."
 ctest --output-on-failure
+echo "travis_fold:end:ctest"
 
