@@ -79,18 +79,13 @@ bool CommandApplyChanges::setup(const std::vector<std::string>& arguments) {
 }
 
 void CommandApplyChanges::show_arguments() {
-    m_vout << "Started osmium apply-changes\n";
-
-    m_vout << "Command line options and default settings:\n";
-    m_vout << "  generator: " << m_generator << "\n";
     m_vout << "  input data file name: " << m_input_filename << "\n";
     m_vout << "  input change file names: \n";
     for (const auto& fn : m_change_filenames) {
         m_vout << "    " << fn << "\n";
     }
-    m_vout << "  output filename: " << m_output_filename << "\n";
     m_vout << "  input format: " << m_input_format << "\n";
-    m_vout << "  output format: " << m_output_format << "\n";
+    show_output_arguments(m_vout);
 }
 
 /**
@@ -139,6 +134,7 @@ bool CommandApplyChanges::run() {
             osmium::apply(buffer, objects);
             changes.push_back(std::move(buffer));
         }
+        reader.close();
     }
 
     m_vout << "Opening input file...\n";
@@ -148,8 +144,10 @@ bool CommandApplyChanges::run() {
     header.set("generator", m_generator);
 
     m_vout << "Opening output file...\n";
-    osmium::io::Writer writer(m_output_file, header, m_output_overwrite);
-    osmium::io::OutputIterator<osmium::io::Writer> out(writer);
+    osmium::io::Writer writer(m_output_file, header, m_output_overwrite, m_fsync);
+    auto out = osmium::io::make_output_iterator(writer);
+
+    auto input = osmium::io::make_input_iterator_range<osmium::OSMObject>(reader);
 
     if (m_simplify_change) {
         // If the --simplify option was given we sort with the
@@ -165,8 +163,8 @@ bool CommandApplyChanges::run() {
         m_vout << "Applying changes and writing them to output...\n";
         std::set_union(objects.begin(),
                        objects.end(),
-                       osmium::io::InputIterator<osmium::io::Reader, osmium::OSMObject> {reader},
-                       osmium::io::InputIterator<osmium::io::Reader, osmium::OSMObject> {},
+                       input.begin(),
+                       input.end(),
                        output_it,
                        osmium::object_order_type_id_reverse_version());
     } else {
@@ -179,13 +177,13 @@ bool CommandApplyChanges::run() {
         m_vout << "Applying changes and writing them to output...\n";
         std::set_union(objects.begin(),
                        objects.end(),
-                       osmium::io::InputIterator<osmium::io::Reader, osmium::OSMObject> {reader},
-                       osmium::io::InputIterator<osmium::io::Reader, osmium::OSMObject> {},
+                       input.begin(),
+                       input.end(),
                        out);
     }
 
-    out.flush();
     writer.close();
+    reader.close();
 
     m_vout << "Done.\n";
 
