@@ -26,9 +26,9 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <string>
 #include <vector>
 
-#include "osmc.hpp"
+#include "cmd.hpp"
 
-class CommandApplyChanges : public Command, with_single_osm_input, with_osm_output {
+class CommandApplyChanges : public Command, public with_single_osm_input, public with_osm_output {
 
     std::vector<std::string> m_change_filenames;
 
