@@ -26,11 +26,12 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <string>
 #include <vector>
 
+#include <osmium/io/header.hpp>
 #include <osmium/osm/entity_bits.hpp>
 
-#include "osmc.hpp"
+#include "cmd.hpp"
 
-class CommandCat : public Command, with_multiple_osm_inputs, with_osm_output {
+class CommandCat : public Command, public with_multiple_osm_inputs, public with_osm_output {
 
     osmium::osm_entity_bits::type m_osm_entity_bits = osmium::osm_entity_bits::all;
 
@@ -44,6 +45,12 @@ public:
 
     bool run() override final;
 
+    void setup_header(osmium::io::Header& header) const;
+
+    osmium::osm_entity_bits::type osm_entity_bits() const {
+        return m_osm_entity_bits;
+    }
+
 }; // class CommandCat
 
 
