@@ -74,13 +74,10 @@ bool CommandCheckRefs::setup(const std::vector<std::string>& arguments) {
 }
 
 void CommandCheckRefs::show_arguments() {
-    m_vout << "Started osmium check-refs\n";
-
-    m_vout << "Command line options and default settings:\n";
-    m_vout << "  input filename: " << m_input_filename << "\n";
-    m_vout << "  input format: " << m_input_format << "\n";
-    m_vout << "  show ids: " << (m_show_ids ? "yes\n" : "no\n");
-    m_vout << "  check relations: " << (m_check_relations ? "yes\n" : "no\n");
+    show_single_input_arguments(m_vout);
+    m_vout << "  other options:\n";
+    m_vout << "    show ids: " << (m_show_ids ? "yes\n" : "no\n");
+    m_vout << "    check relations: " << (m_check_relations ? "yes\n" : "no\n");
 }
 
 class RefCheckHandler : public osmium::handler::Handler {
@@ -254,6 +251,7 @@ bool CommandCheckRefs::run() {
         handler.show_missing_relation_ids();
     }
 
+    reader.close();
     m_vout << "Done.\n";
 
     return !handler.any_errors();
