@@ -25,9 +25,9 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <string>
 
-#include "osmc.hpp"
+#include "cmd.hpp"
 
-class CommandCheckRefs : public Command, with_single_osm_input {
+class CommandCheckRefs : public Command, public with_single_osm_input {
 
     bool m_show_ids = false;
     bool m_check_relations = false;
