@@ -26,12 +26,13 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <string>
 #include <vector>
 
+#include <osmium/osm/entity_bits.hpp>
 #include <osmium/osm/item_type.hpp>
 #include <osmium/osm/types.hpp>
 
-#include "osmc.hpp"
+#include "cmd.hpp"
 
-class CommandGetId : public Command, with_single_osm_input, with_osm_output {
+class CommandGetId : public Command, public with_single_osm_input, public with_osm_output {
 
     std::vector<osmium::object_id_type> m_ids[3];
 
@@ -40,6 +41,7 @@ public:
     CommandGetId() = default;
 
     std::vector<osmium::object_id_type>& ids(osmium::item_type type) noexcept;
+    const std::vector<osmium::object_id_type>& ids(osmium::item_type type) const noexcept;
 
     void sort_unique(osmium::item_type type);
 
@@ -47,6 +49,8 @@ public:
 
     void show_arguments() override final;
 
+    osmium::osm_entity_bits::type get_needed_types() const;
+
     bool run() override final;
 
 }; // class CommandGetId
