@@ -69,20 +69,17 @@ bool CommandMergeChanges::setup(const std::vector<std::string>& arguments) {
 }
 
 void CommandMergeChanges::show_arguments() {
-    m_vout << "Started osmium merge-changes\n";
-
-    m_vout << "Command line options and default settings:\n";
-    m_vout << "  generator: " << m_generator << "\n";
-    m_vout << "  input change file names: \n";
-    for (const auto& fn : m_input_filenames) {
-        m_vout << "    " << fn << "\n";
-    }
-    m_vout << "  output filename: " << m_output_filename << "\n";
-    m_vout << "  input format: " << m_input_format << "\n";
-    m_vout << "  output format: " << m_output_format << "\n";
+    show_multiple_inputs_arguments(m_vout);
+    show_output_arguments(m_vout);
 }
 
 bool CommandMergeChanges::run() {
+    m_vout << "Opening output file...\n";
+    osmium::io::Header header;
+    header.set("generator", m_generator);
+    osmium::io::Writer writer(m_output_file, header, m_output_overwrite, m_fsync);
+    auto out = osmium::io::make_output_iterator(writer);
+
     // this will contain all the buffers with the input data
     std::vector<osmium::memory::Buffer> changes;
 
@@ -97,15 +94,9 @@ bool CommandMergeChanges::run() {
             osmium::apply(buffer, objects);
             changes.push_back(std::move(buffer));
         }
+        reader.close();
     }
 
-    osmium::io::Header header;
-    header.set("generator", m_generator);
-
-    m_vout << "Opening output file...\n";
-    osmium::io::Writer writer(m_output_file, header, m_output_overwrite);
-    osmium::io::OutputIterator<osmium::io::Writer> out(writer);
-
     // Now we sort all objects and write them in order into the
     // output_buffer, flushing the output_buffer whenever it is full.
     if (m_simplify_change) {
@@ -125,7 +116,7 @@ bool CommandMergeChanges::run() {
         std::copy(objects.cbegin(), objects.cend(), out);
     }
 
-    out.flush();
+    m_vout << "Closing output file...\n";
     writer.close();
 
     m_vout << "Done.\n";
