@@ -1,5 +1,4 @@
 /*
-
 Osmium -- OpenStreetMap data manipulation command line tool
 http://osmcode.org/osmium
 
@@ -29,6 +28,10 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <sys/stat.h>
 #include <vector>
 
+#ifdef _WIN32
+# include <io.h>
+#endif
+
 #include <boost/program_options.hpp>
 
 #include <osmium/index/index.hpp>
@@ -77,19 +80,11 @@ bool CommandRenumber::setup(const std::vector<std::string>& arguments) {
 }
 
 void CommandRenumber::show_arguments() {
-    m_vout << "Started osmium renumber\n";
+    show_single_input_arguments(m_vout);
+    show_output_arguments(m_vout);
 
-    m_vout << "Command line options and default settings:\n";
-    m_vout << "  generator: " << m_generator << "\n";
-    m_vout << "  input filename: " << m_input_filename << "\n";
-    m_vout << "  output filename: " << m_output_filename << "\n";
-    m_vout << "  input format: " << m_input_format << "\n";
-    m_vout << "  output format: " << m_output_format << "\n";
-    m_vout << "  output header: \n";
-    for (const auto& h : m_output_headers) {
-        m_vout << "    " << h << "\n";
-    }
-    m_vout << "  index directory: " << m_index_directory << "\n";
+    m_vout << "  other options:\n";
+    m_vout << "    index directory: " << m_index_directory << "\n";
 }
 
 osmium::object_id_type CommandRenumber::lookup(osmium::item_type type, osmium::object_id_type id) {
@@ -141,21 +136,33 @@ void CommandRenumber::read_index(osmium::item_type type, const std::string& name
     std::string f { filename(name) };
     int fd = ::open(f.c_str(), O_RDONLY);
     if (fd < 0) {
-        // ignore if the file is not there
+        // if the file is not there we don't have to read anything and can return
         if (errno == ENOENT) {
             return;
         }
-        std::runtime_error(std::string("Can't open file '") + f + "': " + strerror(errno));
+        throw std::runtime_error(std::string("Can't open file '") + f + "': " + strerror(errno));
     }
+#ifdef _WIN32
+    _setmode(fd, _O_BINARY);
+#endif
 
     size_t file_size = osmium::util::file_size(fd);
-    if (file_size % sizeof(remap_index_type::value_type) == 0) {
-        std::runtime_error(std::string("index file '") + f + "' has wrong file size");
+    if (file_size % sizeof(remap_index_value_type) != 0) {
+        throw std::runtime_error(std::string("index file '") + f + "' has wrong file size");
     }
-    osmium::util::TypedMemoryMapping<remap_index_type::value_type> mapping(file_size / sizeof(remap_index_type::value_type), false, fd);
-    std::copy(mapping.begin(), mapping.end(), std::inserter(index(type), index(type).begin()));
 
-    last_id(type) = std::max_element(mapping.begin(), mapping.end())->second;
+    {
+        osmium::util::TypedMemoryMapping<remap_index_value_type> mapping(file_size / sizeof(remap_index_value_type), osmium::util::MemoryMapping::mapping_mode::readonly, fd);
+        std::copy(mapping.begin(), mapping.end(), std::inserter(index(type), index(type).begin()));
+
+        last_id(type) = std::max_element(mapping.begin(),
+                                         mapping.end(),
+                                         [](const remap_index_value_type& a,
+                                            const remap_index_value_type& b) {
+                                             return a.second < b.second;
+                                         }
+                        )->second;
+    }
 
     close(fd);
 }
@@ -164,69 +171,66 @@ void CommandRenumber::write_index(osmium::item_type type, const std::string& nam
     std::string f { filename(name) };
     int fd = ::open(f.c_str(), O_WRONLY | O_CREAT, 0666);
     if (fd < 0) {
-        std::runtime_error(std::string("Can't open file '") + f + "': " + strerror(errno));
+        throw std::runtime_error(std::string("Can't open file '") + f + "': " + strerror(errno));
     }
+#ifdef _WIN32
+    _setmode(fd, _O_BINARY);
+#endif
 
-    std::vector<remap_index_type::value_type> data;
+    std::vector<remap_index_value_type> data;
     std::copy(index(type).begin(), index(type).end(), std::back_inserter(data));
-    osmium::io::detail::reliable_write(fd, reinterpret_cast<const char*>(data.data()), sizeof(remap_index_type::value_type) * data.size());
+    osmium::io::detail::reliable_write(fd, reinterpret_cast<const char*>(data.data()), sizeof(remap_index_value_type) * data.size());
 
     close(fd);
 }
 
 bool CommandRenumber::run() {
-    try {
-        if (!m_index_directory.empty()) {
-            m_vout << "Reading index files...\n";
-            read_index(osmium::item_type::node, "nodes");
-            read_index(osmium::item_type::way, "ways");
-            read_index(osmium::item_type::relation, "relations");
+    if (!m_index_directory.empty()) {
+        m_vout << "Reading index files...\n";
+        read_index(osmium::item_type::node, "nodes");
+        read_index(osmium::item_type::way, "ways");
+        read_index(osmium::item_type::relation, "relations");
 
-            m_vout << "  Nodes     index contains " << index(osmium::item_type::node).size()     << " items\n";
-            m_vout << "  Ways      index contains " << index(osmium::item_type::way).size()      << " items\n";
-            m_vout << "  Relations index contains " << index(osmium::item_type::relation).size() << " items\n";
-        }
+        m_vout << "  Nodes     index contains " << index(osmium::item_type::node).size()     << " items\n";
+        m_vout << "  Ways      index contains " << index(osmium::item_type::way).size()      << " items\n";
+        m_vout << "  Relations index contains " << index(osmium::item_type::relation).size() << " items\n";
+    }
 
-        m_vout << "First pass through input file (reading relations)...\n";
-        osmium::io::Reader reader_pass1(m_input_file, osmium::osm_entity_bits::relation);
+    m_vout << "First pass through input file (reading relations)...\n";
+    osmium::io::Reader reader_pass1(m_input_file, osmium::osm_entity_bits::relation);
 
-        osmium::io::Header header = reader_pass1.header();
-        header.set("generator", m_generator);
-        header.set("xml_josm_upload", "false");
-        for (const auto& h : m_output_headers) {
-            header.set(h);
-        }
-        osmium::io::Writer writer(m_output_file, header, m_output_overwrite);
+    m_vout << "Opening output file...\n";
+    osmium::io::Header header = reader_pass1.header();
+    header.set("generator", m_generator);
+    header.set("xml_josm_upload", "false");
+    for (const auto& h : m_output_headers) {
+        header.set(h);
+    }
+    osmium::io::Writer writer(m_output_file, header, m_output_overwrite, m_fsync);
 
-        osmium::io::InputIterator<osmium::io::Reader, osmium::Relation> it { reader_pass1 };
-        osmium::io::InputIterator<osmium::io::Reader, osmium::Relation> end {};
+    auto input = osmium::io::make_input_iterator_range<osmium::Relation>(reader_pass1);
+    for (const osmium::Relation& relation : input) {
+        lookup(osmium::item_type::relation, relation.id());
+    }
 
-        for (; it != end; ++it) {
-            lookup(osmium::item_type::relation, it->id());
-        }
+    reader_pass1.close();
 
-        reader_pass1.close();
+    m_vout << "Second pass through input file...\n";
+    osmium::io::Reader reader_pass2(m_input_file);
+    while (osmium::memory::Buffer buffer = reader_pass2.read()) {
+        renumber(buffer);
+        writer(std::move(buffer));
+    }
+    reader_pass2.close();
 
-        m_vout << "Second pass through input file...\n";
-        osmium::io::Reader reader_pass2(m_input_file);
-        while (osmium::memory::Buffer buffer = reader_pass2.read()) {
-            renumber(buffer);
-            writer(std::move(buffer));
-        }
-        reader_pass2.close();
+    m_vout << "Closing output file...\n";
+    writer.close();
 
-        writer.close();
-
-        if (!m_index_directory.empty()) {
-            m_vout << "Writing index files...\n";
-            write_index(osmium::item_type::node, "nodes");
-            write_index(osmium::item_type::way, "ways");
-            write_index(osmium::item_type::relation, "relations");
-        }
-
-    } catch (std::exception& e) {
-        std::cerr << e.what() << "\n";
-        return false;
+    if (!m_index_directory.empty()) {
+        m_vout << "Writing index files...\n";
+        write_index(osmium::item_type::node, "nodes");
+        write_index(osmium::item_type::way, "ways");
+        write_index(osmium::item_type::relation, "relations");
     }
 
     m_vout << "Done.\n";
