@@ -20,6 +20,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 */
 
+#include <stdexcept>
+
 #include <boost/program_options.hpp>
 
 #include <osmium/io/any_input.hpp>
@@ -29,6 +31,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <osmium/diff_iterator.hpp>
 
 #include "command_time_filter.hpp"
+#include "exception.hpp"
 
 bool CommandTimeFilter::setup(const std::vector<std::string>& arguments) {
     po::options_description cmdline("Allowed options");
@@ -64,17 +67,28 @@ bool CommandTimeFilter::setup(const std::vector<std::string>& arguments) {
     m_to = m_from;
 
     if (vm.count("time-from")) {
-        m_from = osmium::Timestamp(vm["time-from"].as<std::string>().c_str());
+        auto ts = vm["time-from"].as<std::string>();
+        try {
+            m_from = osmium::Timestamp(ts);
+        } catch (std::invalid_argument&) {
+            throw argument_error("Wrong format for (first) timestamp (use YYYY-MM-DDThh:mm:ssZ).");
+        }
         m_to = m_from;
     }
 
     if (vm.count("time-to")) {
-        m_to = osmium::Timestamp(vm["time-to"].as<std::string>().c_str());
-        if (m_to < m_from) {
-            throw argument_error("Second timestamp is before first one.");
+        auto ts = vm["time-to"].as<std::string>();
+        try {
+            m_to = osmium::Timestamp(ts);
+        } catch (std::invalid_argument&) {
+            throw argument_error("Wrong format for second timestamp (use YYYY-MM-DDThh:mm:ssZ).");
         }
     }
 
+    if (m_from > m_to) {
+        throw argument_error("Second timestamp is before first one.");
+    }
+
     if (m_from == m_to) { // point in time
         if (m_output_file.has_multiple_object_versions()) {
             std::cerr << "Warning! You are writing to a file marked as having multiple object versions,\n";
@@ -91,51 +105,51 @@ bool CommandTimeFilter::setup(const std::vector<std::string>& arguments) {
 }
 
 void CommandTimeFilter::show_arguments() {
-    m_vout << "Started osmium time-filter\n";
-    m_vout << "Filtering from time " << m_from.to_iso() << " to " << m_to.to_iso() << "\n";
+    show_single_input_arguments(m_vout);
+    show_output_arguments(m_vout);
+    m_vout << "  other options:\n";
+    m_vout << "    Filtering from time " << m_from.to_iso() << " to " << m_to.to_iso() << "\n";
 }
 
 bool CommandTimeFilter::run() {
     m_vout << "Opening input file...\n";
     osmium::io::Reader reader(m_input_file, osmium::osm_entity_bits::object);
 
+    m_vout << "Opening output file...\n";
     osmium::io::Header header = reader.header();
     header.set("generator", m_generator);
+    osmium::io::Writer writer(m_output_file, header, m_output_overwrite, m_fsync);
 
-    m_vout << "Opening output file...\n";
-    osmium::io::Writer writer(m_output_file, header, m_output_overwrite);
-    osmium::io::OutputIterator<osmium::io::Writer> out(writer);
-
-    typedef osmium::io::InputIterator<osmium::io::Reader, osmium::OSMObject> object_iterator;
-
-    object_iterator object_it(reader);
-    object_iterator object_end;
-
-    typedef osmium::DiffIterator<object_iterator> diff_iterator;
-
-    m_vout << "Filtering data...\n";
+    m_vout << "Filter data while copying it from input to output...\n";
+    auto input = osmium::io::make_input_iterator_range<osmium::OSMObject>(reader);
+    auto diff_begin = osmium::make_diff_iterator(input.begin(), input.end());
+    auto diff_end   = osmium::make_diff_iterator(input.end(), input.end());
+    auto out = osmium::io::make_output_iterator(writer);
 
     if (m_from == m_to) {
         std::copy_if(
-            diff_iterator(object_it, object_end),
-            diff_iterator(object_end, object_end),
+            diff_begin,
+            diff_end,
             out,
             [this](const osmium::DiffObject& d){
                 return d.is_visible_at(m_from);
         });
     } else {
         std::copy_if(
-            diff_iterator(object_it, object_end),
-            diff_iterator(object_end, object_end),
+            diff_begin,
+            diff_end,
             out,
             [this](const osmium::DiffObject& d){
                 return d.is_between(m_from, m_to);
         });
     }
 
-    out.flush();
+    m_vout << "Closing output file...\n";
     writer.close();
 
+    m_vout << "Closing input file...\n";
+    reader.close();
+
     m_vout << "Done.\n";
 
     return true;
