@@ -24,16 +24,12 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <string>
 #include <vector>
 
-#include <osmpbf/osmpbf.h>
+#ifdef _WIN32
+# include <fcntl.h>
+# include <io.h>
+#endif
 
-#include "osmc.hpp"
-
-#include "command_apply_changes.hpp"
-#include "command_cat.hpp"
-#include "command_fileinfo.hpp"
-#include "command_help.hpp"
-#include "command_merge_changes.hpp"
-#include "command_time_filter.hpp"
+#include "cmd.hpp"
 
 enum return_code : int {
     okay  = 0,
@@ -42,6 +38,10 @@ enum return_code : int {
 };
 
 int main(int argc, char *argv[]) {
+#ifdef _WIN32
+    _setmode(1, _O_BINARY);
+#endif
+
     std::string command = argv[0];
 
     // remove path from command
@@ -104,15 +104,16 @@ int main(int argc, char *argv[]) {
         return return_code::fatal;
     }
 
-    cmd->print_arguments();
-    bool result = cmd->run();
+    cmd->print_arguments(command);
 
-    google::protobuf::ShutdownProtobufLibrary();
-
-    if (result) {
-        return return_code::okay;
-    } else {
-        return return_code::error;
+    try {
+        if (cmd->run()) {
+            return return_code::okay;
+        }
+    } catch (std::exception& e) {
+        std::cerr << e.what() << "\n";
     }
+
+    return return_code::error;
 }
 
